using Fuel.Core.Models;
using Fuel.Core.Nozzle.Dto;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Fuel.Application.Service
{
    public interface INozzleService
    {
        Task<ServiceResponse> UploadNozzle(UploadNozzle uploadNozzle);
        Task<ServiceResponse> UpdateNozzle(UploadNozzle uploadNozzle);
        Task<ServiceResponse> DeleteNozzle(UploadNozzle uploadNozzle);
        Task<List<NozzleInfo>> GetNozzleInfo(int Nozzleid);
        Task<ServiceResponse> UploadProduct(UploadProduct uploadProduct);
        Task<ServiceResponse> UpdateProduct(UploadProduct uploadProduct);
        Task<ServiceResponse> DeleteProduct(UploadProduct uploadProduct);
        Task<ServiceResponse> UploadTanks(UploadTanks uploadTanks);
        Task<ServiceResponse> UpdateTanks(UploadTanks uploadTanks);
        Task<ServiceResponse> DeleteTanks(UploadTanks uploadTanks);
        Task<ServiceResponse> UpdateNozzleStatus(List<UploadNozzleStatus> uploadNozzleStatuses);
    }
}
